//
// helpdlg.cpp
// ~~~~~~~~~~~
// Context-Help Dialog Example
//

#include <owl/pch.h>
#include <owl/hlpmanag.h>

#include "helpdlg.rh"
#include "helpdlg.h"


// ---------------------------------------------------------
// THelpDialog class
// ~~~~~~~~~~~~~~~~~
// An example dialog with context help.
//

class THelpDialog : public TDialog
{
  public:
    THelpDialog(TWindow* parent);
    ~THelpDialog();
    DECLARE_HELPCONTEXT(THelpDialog);
};



// ---------------------------------------------------------
// THelpApp class
// ~~~~~~~~~~~~~~
// Your application class should be derived from
// THelpFileManager to enable context help.
//

class THelpApp : public TApplication, public THelpFileManager
{
  public:
    THelpApp();
    void InitMainWindow();
    void ActivateHelp(TWindow *wnd, int contextId);
    void CmFileDialog();
    DECLARE_RESPONSE_TABLE(THelpApp);
};



// ---------------------------------------------------------
// THelpDialog implementation
// ~~~~~~~~~~~~~~~~~~~~~~~~~~
//


//
// Define the help context associations for the dialog
//
DEFINE_HELPCONTEXT(THelpDialog)
  HCENTRY_CONTROL(IDH_OKBUTTON,     IDOK),
  HCENTRY_CONTROL(IDH_CANCELBUTTON, IDCANCEL),
  HCENTRY_CONTROL(IDH_EDITBOX,      IDC_EDIT),
  HCENTRY_CONTROL(IDH_LISTBOX,      IDC_LISTBOX),
END_HELPCONTEXT;


THelpDialog::THelpDialog(TWindow* parent)
: TDialog(parent, IDD_CONTEXTHELP)
{
  SETUP_HELPCONTEXT(THelpApp, THelpDialog);
}


THelpDialog::~THelpDialog()
{
  Destroy(IDCANCEL);
  CLEANUP_HELPCONTEXT(THelpApp, THelpDialog);
}



// ---------------------------------------------------------
// THelpApp implementation
// ~~~~~~~~~~~~~~~~~~~~~~~
//

DEFINE_RESPONSE_TABLE2(THelpApp, TApplication, THelpFileManager)
  EV_COMMAND(CM_FILEDIALOG, CmFileDialog),
END_RESPONSE_TABLE;


THelpApp::THelpApp()
: TApplication("Context Help Example Application"),
  THelpFileManager(".\\helpdlg.hlp")
{
}


void THelpApp::InitMainWindow()
{
  TFrameWindow* frame = new TFrameWindow(0, GetName());
  SetMainWindow(frame);
  frame->SetMenuDescr(TMenuDescr(IDM_SDI));
}


void THelpApp::CmFileDialog()
{
  THelpDialog(GetMainWindow()).Execute();
}


//
// Override THelpManager::ActivateHelp to use popup help
// windows instead of the default normal window
//
void THelpApp::ActivateHelp(TWindow */*wnd*/, int contextId)
{
  GetMainWindow()->WinHelp(GetHelpFile().c_str(), HELP_CONTEXTPOPUP, contextId);
}



int OwlMain(int, char*[])
{
  return THelpApp().Run();
}
